import React, {useContext, useState} from "react";
import {Button, Form, Input, message, Modal, Select, Space, Table,} from "antd";
import {observer} from "mobx-react-lite";
import {useHistory} from "react-router-dom";
import {useStore} from "../utils/useStore";
import {ModalLoaderContext} from "../utils/modal";

export const SubcategoryComponent = observer((props) => {
  const store = useStore();
  const [form] = Form.useForm();
  const {Option} = Select;
  const [idData, setIdData] = useState("");
  const modalLoader = useContext(ModalLoaderContext);

  const getData = async () => {
    await store.category.getData();
    await store.subcategory.getData();
  };

  const handleEditButton = (data) => {
    console.log(data, "isi data");
    form.setFieldsValue({
      code: data.code,
      name: data.name,
      categoryId: data.categoryId,
    });
    store.subcategory.visibleModalSubcategory = true;
    setIdData(data.id);
  };

  const columns = [
    {
      title: "Code",
      dataIndex: "code",
      key: "code",
    },
    {
      title: "Sub Category Name",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "Category",
      dataIndex: "categoryName",
      key: "categoryName",
    },
    {
      title: "Action",
      key: "action",
      render: (text, record) => (
        <Space size="middle">
          <Button onClick={() => handleEditButton(record)}>Edit</Button>
        </Space>
      ),
    },
  ];

  const handleCancel = () => {
    setIdData("");
    store.subcategory.visibleModalSubcategory = false;
  };

  const handleSubmit = async (data) => {
    console.log(data, "isi data2");
    if (idData !== "") {
      modalLoader.setLoading(true);
      try {
        await store.subcategory.update(idData, data);
        await getData();
        message.success("Success Update Data Category");
      } catch (e) {
        message.error("Failed Update Data Category");
      }
      modalLoader.setLoading(false);
      store.subcategory.visibleModalSubcategory = false;
      setIdData("");
      form.resetFields();
    } else {
      modalLoader.setLoading(true);
      try {
        await store.subcategory.create(data);
        await getData();
        message.success("Success Add New Category");
      } catch (e) {
        console.log(e, "apa errornya");
        message.error("Failed Add Category");
      }
      modalLoader.setLoading(false);
      store.subcategory.visibleModalSubcategory = false;
      setIdData("");
      form.resetFields();
    }
  };

  return (
    <div>
      <Table
        style={{textAlign: "center"}}
        columns={columns}
        dataSource={store.subcategory.data}
        bordered
        pagination={{
          pageSize: store.subcategory.pageSize,
          total: store.subcategory.total_data,
          current: store.subcategory.page + 1,
          showSizeChanger: true,
          simple: false,
        }}
        onChange={async (page) => {
          let pageNumber = page.current;
          store.subcategory.pageSize = page.pageSize;
          store.subcategory.page = pageNumber - 1;
          modalLoader.setLoading(true);
          await getData();
          modalLoader.setLoading(false);
        }}
      />

      <Modal
        visible={store.subcategory.visibleModalSubcategory}
        title={idData ? "Edit Sub Category" : "Create a new sub category"}
        okText={idData ? "Edit" : "Create"}
        cancelText="Cancel"
        onCancel={() => {
          form.resetFields();
          handleCancel();
        }}
        onOk={() => {
          form
            .validateFields()
            .then((values) => {
              console.log(values, "isi form");
              handleSubmit(values);
              form.resetFields();
            })
            .catch((info) => {
              console.error("Validate Failed:", info);
            });
        }}
      >
        <Form form={form} layout="vertical">
          {!idData && (
            <Form.Item
              name="code"
              label="Code"
              rules={[
                {required: true, message: "Please input code category!"},
              ]}
            >
              <Input/>
            </Form.Item>
          )}
          <Form.Item
            name="name"
            label="Name"
            rules={[{required: true, message: "Please input name category!"}]}
          >
            <Input/>
          </Form.Item>
          {!idData && (
            <Form.Item
              name="categoryId"
              label="Categories"
              rules={[{required: true, message: "Please input category id!"}]}
            >
              <Select placeholder="Select Category" allowClear>
                {store.category.data.map((item) => (
                  <Option value={item.id} key={item.id}>
                    {item.name}
                  </Option>
                ))}
              </Select>
            </Form.Item>
          )}
        </Form>
      </Modal>
    </div>
  );
});
